pub struct IanaParserExtended<I> {
inner: I,
data: DataPayload<TimezoneIdentifiersIanaExtendedV1>,
}Expand description
A parser that supplements IanaParser with about 10kB of additional data to support
returning canonical and case-normalized IANA time zone IDs.
Fields
inner: Idata: DataPayload<TimezoneIdentifiersIanaExtendedV1>Implementations
Sourceimpl IanaParserExtended<IanaParser>
impl IanaParserExtended<IanaParser>
Sourcepub fn new() -> IanaParserExtendedBorrowed<'static>
pub fn new() -> IanaParserExtendedBorrowed<'static>
Creates a new IanaParserExtended using compiled data.
See IanaParserExtended for an example.
✨ Enabled with the compiled_data Cargo feature.
Sourcepub fn try_new_unstable<P>(provider: &P) -> Result<Self, DataError>
pub fn try_new_unstable<P>(provider: &P) -> Result<Self, DataError>
A version of Self::new that uses custom data provided by a DataProvider.
⚠️ The bounds on provider may change over time, including in SemVer minor releases.
Sourceimpl<I> IanaParserExtended<I>where
I: AsRef<IanaParser>,
impl<I> IanaParserExtended<I>where
I: AsRef<IanaParser>,
Sourcepub fn try_new_with_parser(parser: I) -> Result<Self, DataError>
pub fn try_new_with_parser(parser: I) -> Result<Self, DataError>
Creates a new IanaParserExtended using compiled data
and a pre-existing IanaParser, which can be borrowed.
See IanaParserExtended for an example.
✨ Enabled with the compiled_data Cargo feature.
Sourcepub fn try_new_with_parser_unstable<P>(
provider: &P,
parser: I,
) -> Result<Self, DataError>
pub fn try_new_with_parser_unstable<P>( provider: &P, parser: I, ) -> Result<Self, DataError>
A version of Self::new that uses custom data provided by a DataProvider.
⚠️ The bounds on provider may change over time, including in SemVer minor releases.
Sourcepub fn as_borrowed(&self) -> IanaParserExtendedBorrowed<'_>
pub fn as_borrowed(&self) -> IanaParserExtendedBorrowed<'_>
Returns a borrowed version of the parser that can be queried.
This avoids a small potential indirection cost when querying the parser.